RustParser

Struct RustParser 

pub struct RustParser { /* private fields */ }
Tree-sitter parser wrapper for Rust source code.

Implementations

Source

impl RustParser

pub fn new() -> Result<Self, TreeSitterError>

Create a new Rust parser with the default edition (2021).

pub fn with_edition(edition: RustEdition) -> Result<Self, TreeSitterError>

Create a new Rust parser targeting a specific edition.

pub fn edition(&self) -> RustEdition

Get the configured edition.

pub fn parse(&mut self, source: &str) -> Result<Tree, TreeSitterError>

Parse source code into a tree-sitter Tree.

pub fn parse_with_source<'a>( &mut self, source: &'a str, ) -> Result<ParsedSource<'a>, TreeSitterError>

Parse source code and return the tree along with the source.